@@ -404,6 +404,8 @@ class MetaModelTestCase(unittest.TestCase):
         prob['x'] = 0.125
         prob.run_model()
 
+        mm._no_check_partials = False  # override skipping of check_partials
+
         data = prob.check_partials(out_stream=None)
 
         Jf = data['mm'][('f', 'x')]['J_fwd']
@@ -668,12 +670,12 @@ class MetaModelTestCase(unittest.TestCase):
         with self.assertRaises(RuntimeError) as cm:
             mm.add_input('x', np.zeros(2))
         self.assertEqual(str(cm.exception),
-                         "MetaModelUnStructuredComp: First dimension of input 'x' must be 3")
+                         "<class MetaModelUnStructuredComp>: First dimension of input 'x' must be 3")
 
         with self.assertRaises(RuntimeError) as cm:
             mm.add_output('y', np.zeros(4))
         self.assertEqual(str(cm.exception),
-                         "MetaModelUnStructuredComp: First dimension of output 'y' must be 3")
+                         "<class MetaModelUnStructuredComp>: First dimension of output 'y' must be 3")
 
     def test_metamodel_subclass_optimize(self):
         class Trig(om.MetaModelUnStructuredComp):
@@ -788,7 +790,7 @@ class MetaModelTestCase(unittest.TestCase):
               "The derivatives computed using the defaults are:\n" \
               "    trig.sin_x, trig.x\n"
 
-        with assert_warning(RuntimeWarning, msg):
+        with assert_warning(om.DerivativesWarning, msg):
             prob = no_surrogate_test_setup(trig)
 
         J = prob.compute_totals(of=['trig.sin_x'], wrt=['indep.x'])
@@ -861,7 +863,7 @@ class MetaModelTestCase(unittest.TestCase):
               "The derivatives computed using the defaults are:\n" \
               "    trig.sin_x, trig.x2\n"
 
-        with assert_warning(RuntimeWarning, msg):
+        with assert_warning(om.DerivativesWarning, msg):
             prob.run_model()
 
         self.assertEqual('fd', trig._subjacs_info[('trig.sin_x', 'trig.x1')]['method'])
