@@ -11,7 +11,7 @@ from openmdao.utils.general_utils import set_pyoptsparse_opt
 from openmdao.utils.mpi import MPI
 
 from openmdao.api import ExecComp, ExplicitComponent, Problem, \
-    Group, ParallelGroup, IndepVarComp, SqliteRecorder, ScipyOptimizeDriver
+    Group, ParallelGroup, IndepVarComp, SqliteRecorder, ScipyOptimizeDriver, slicer
 from openmdao.utils.array_utils import evenly_distrib_idxs
 from openmdao.recorders.tests.sqlite_recorder_test_utils import \
     assertDriverIterDataRecorded, assertProblemDataRecorded
@@ -121,7 +121,7 @@ class DistributedRecorderTest(unittest.TestCase):
         try:
             prob.model.add_recorder(self.recorder)
         except RuntimeError as err:
-            msg = "Group: Recording of Systems when running parallel code is not supported yet"
+            msg = "<class Group>: Recording of Systems when running parallel code is not supported yet"
             self.assertEqual(str(err), msg)
         else:
             self.fail('RuntimeError expected.')
@@ -142,7 +142,8 @@ class DistributedRecorderTest(unittest.TestCase):
 
         prob.model.add_subsystem('des_vars', IndepVarComp('x', np.ones(size)), promotes=['x'])
         prob.model.add_subsystem('plus', DistributedAdder(size), promotes=['x', 'y'])
-        prob.model.add_subsystem('summer', Summer(size), promotes=['y', 'sum'])
+        prob.model.add_subsystem('summer', Summer(size), promotes_outputs=['sum'])
+        prob.model.promotes('summer', inputs=['y'], src_indices=slicer[:])
         prob.driver.recording_options['record_desvars'] = True
         prob.driver.recording_options['record_objectives'] = True
         prob.driver.recording_options['record_constraints'] = True
@@ -216,7 +217,7 @@ class DistributedRecorderTest(unittest.TestCase):
         # current values in the problem. This next section is about getting those values
 
         # These involve collective gathers so all ranks need to run this
-        expected_outputs = driver.get_design_var_values()
+        expected_outputs = driver.get_design_var_values(get_remote=True)
         expected_outputs.update(driver.get_objective_values())
         expected_outputs.update(driver.get_constraint_values())
 
